@@ -18,7 +18,6 @@ import contextlib
 import inspect
 import locale
 import os.path
-import re
 import shutil
 import sys
 import tempfile
@@ -107,7 +106,7 @@ class InPlaceSaver(Saver):
         djvu_path = os.path.abspath(djvu_path)
         djvused = ipc.Subprocess(
             ['djvused', '-s', '-f', sed_file_name, djvu_path],
-            env=None,  # preserve locale settings
+            env={},  # preserve locale settings
         )
         djvused.wait()
 
@@ -139,7 +138,7 @@ class Ocropus(OcrEngine):
                 ocropus = ipc.Subprocess(['ocroscript', script_name],
                     stdout=ipc.PIPE,
                     stderr=ipc.PIPE,
-                    env={},  # locale=POSIX
+                    env=dict(LC_ALL=None),  # locale=POSIX
                 )
             except OSError:
                 raise errors.EngineNotFound(self.name)
@@ -182,7 +181,7 @@ class Ocropus(OcrEngine):
             yield pbm_file.name
         ocropus = ipc.Subprocess(list(get_command_line()),
             stdout=ipc.PIPE,
-            env=dict(tesslanguage=language)  # locale=POSIX
+            env=dict(tesslanguage=language, LC_ALL=None),  # locale=POSIX
         )
         try:
             yield ocropus.stdout
