@@ -10,30 +10,37 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
+import os
 import re
 import signal
 import subprocess
 
 PIPE = subprocess.PIPE
 
-try:
-    from subprocess import CalledProcessError
-except ImportError:
-    class CalledProcessError(Exception):
-        def __init__(self, return_code, command):
-            Exception.__init__(self, command, return_code)
-        def __str__(self):
-            return 'Command %r returned non-zero exit status %d' % self.args
+from subprocess import CalledProcessError
 
-_signame_pattern = re.compile('^SIG[A-Z0-9]*$')
-
-class CalledProcessInterrupted(CalledProcessError):
-
-    _signal_names = dict(
-        (getattr(signal, name), name)
+def get_signal_names():
+    _signame_pattern = re.compile('^SIG[A-Z0-9]*$')
+    data = dict(
+        (name, getattr(signal, name))
         for name in dir(signal)
         if _signame_pattern.match(name)
     )
+    try:
+        if data['SIGABRT'] == data['SIGIOT']:
+            del data['SIGIOT']
+    except KeyError:
+        pass
+    try:
+        if data['SIGCHLD'] == data['SIGCLD']:
+            del data['SIGCLD']
+    except KeyError:
+        pass
+    return dict((no, name) for name, no in data.iteritems())
+
+class CalledProcessInterrupted(CalledProcessError):
+
+    _signal_names = get_signal_names()
 
     def __init__(self, signal_id, command):
         Exception.__init__(self, command, signal_id)
@@ -41,12 +48,27 @@ class CalledProcessInterrupted(CalledProcessError):
         signal_name = self._signal_names.get(self.args[1], self.args[1])
         return 'Command %r was interrputed by signal %s' % (self.args[0], signal_name)
 
-del _signame_pattern
+del get_signal_names
 
 class Subprocess(subprocess.Popen):
 
     def __init__(self, *args, **kwargs):
+        env_override = kwargs.pop('env', {})
+        if env_override.get('LC_ALL', '') is None:
+            # Reset all locale variables
+            env = dict(
+                (k, v)
+                for k, v in os.environ.iteritems()
+                if not (k.startswith('LC_') or k in ('LANG', 'LANGUAGES'))
+            )
+            del env_override['LC_ALL']
+        else:
+            env = dict(os.environ)
+        env.update(env_override)
+        kwargs['env'] = env
         subprocess.Popen.__init__(self, *args, **kwargs)
+        if os.name == 'posix':
+            kwargs.update(close_fds=True)
         try:
             self.__command = kwargs['args'][0]
         except KeyError:
